@@ -25,12 +25,14 @@ except NameError:
 
 import gi
 gi.require_version('Gtk', '3.0')
+gi.require_version('Gdk', '3.0')
 from gi.repository import GObject, GLib, Gdk, Gio, Gtk, Pango
 
 try:
+    gi.require_version('AppIndicator3', '0.1')
     from gi.repository import AppIndicator3
     have_app_indicator = True
-except ImportError:
+except (ValueError, ImportError):
     have_app_indicator = False
 
 from gtimelog import __version__
